@@ -781,7 +781,7 @@ WaylandServer (SurfaceRoles)
       break;
     case NSPopUpMenuWindowLevel:
       NSDebugLog(@"[%d] NSPopUpMenuWindowLevel", win);
-      [self createPopup:win];
+      [self createPopup:window];
       break;
     case NSScreenSaverWindowLevel:
       NSDebugLog(@"[%d] NSScreenSaverWindowLevel", win);
@@ -1099,4 +1099,4 @@ WaylandServer (SurfaceRoles)
   wl_display_flush(window->wlconfig->display);
 }
 
-@end
+@end
\ No newline at end of file
